Learn R Programming

corr2D (version 1.0.3)

FuranMale: FT-Raman spectra of furan maleimide based self-healing polymer

Description

Six preprocessed FT-Raman spectra of a self-healing polymer. The wavenumber region shows the C=C vibrations of furan, maleimide and their respective Diels-Alder adduct. The row names show the measurement temperature in degree Celsius, while the column names show the relative wavenumber.

Arguments

Format

A matrix containing 6 spectra by rows with 145 wavenumbers by columns.