corr2t2d compares a pair of spectra in the form of a cross
correlation analysis.
Usage
corr2t2d(Sam, Ref, Wave = NULL, preview = FALSE)
Value
corr2t2d returns a list of class "corr2d" containing the
complex correlation matrix ($FT), the correlation and
disrelation coefficient as a complex matrix ($coef), the sample
$Ref1 and reference spectrum $Ref2 as well as the
spectral variable $Wave1 and $Wave2.
Arguments
Sam
Numeric vector containing the sample spectrum to be correlated.
Can contain the spectral variable of the sample and reference spectrum
as names.
Ref
Numeric vector containing the sample spectrum to be correlated.
Can contain the spectral variable of the sample and reference spectrum
as names.
Wave
Numeric vector containing the spectral variable. Needs to be
specified if names of Sam and Ref are undefined.
preview
Logical: Should a 3D preview of the asynchronous codistribution
spectrum be drawn at the end? Uses persp3d from rgl
package.
Details
corr2t2d implements the Two-trace two-dimensional (2T2D) approach
as described by I. Noda (2018) <DOI:10.1016/j.molstruc.2018.01.091>.
The idea is to compare two spectra in a 2D correlation-like
approach which was previously not possible as 2D correlation analysis
usually needs at least three spectra.
References
I. Noda (2018) <DOI:10.1016/j.molstruc.2018.01.091>
See Also
For plotting of the resulting list containing the 2D correlation
spectra or correlation coefficient see plot_corr2d and
plot_corr2din3d.