Learn R Programming

corr2D (version 1.0.3)

is.corr2d: Check for object class "corr2d"

Description

The function checks if an object is of class "corr2d".

Usage

is.corr2d(x)

Value

A logical scalar

Arguments

x

An object which should be check if it is of class "corr2d".

Details

The function uses the inherits function.

References

R. Geitner et al. (2019) <DOI:10.18637/jss.v090.i03>

Examples

Run this code
    data(FuranMale, package = "corr2D")
    twod <- corr2d(FuranMale, Ref1 = FuranMale[1, ], corenumber = 1)
    
    # TRUE
    is.corr2d(twod) 
    # FALSE
    is.corr2d(2) 

Run the code above in your browser using DataLab