powered by
The function checks if an object is of class "corr2d".
is.corr2d(x)
A logical scalar
An object which should be check if it is of class "corr2d".
The function uses the inherits function.
inherits
R. Geitner et al. (2019) <DOI:10.18637/jss.v090.i03>
data(FuranMale, package = "corr2D") twod <- corr2d(FuranMale, Ref1 = FuranMale[1, ], corenumber = 1) # TRUE is.corr2d(twod) # FALSE is.corr2d(2)
Run the code above in your browser using DataLab